# SeisLog Package

This package ultimately bridges the gap between seismic and log data interpretation. This is not intended to be a replacement for popular data loading packages such as welly, lasio and segysak but instead builds on theses packages to allow the user to correlate between the well data and the seismic data along that wellpath. 

# Contents
- `Make_a_Package` is the project directory for the SeisLog Python package.
- `Make_a_Package/SeisLog` contains the actual "SeisLog package" with accompanying  `__init__.py` file
- `Make_a_Package/demo` is a project directory containing a Jupyter Notebook demonstration

# Installation

- Using Python Package Manager: $ pip install SeisLog
- Using Source: python setup.py install
